from typing import List

from numpy.core.shape_base import vstack

__all__: List[str]

row_stack = vstack

def take_along_axis(arr, indices, axis): ...
def put_along_axis(arr, indices, values, axis): ...
def apply_along_axis(func1d, axis, arr, *args, **kwargs): ...
def apply_over_axes(func, a, axes): ...
def expand_dims(a, axis): ...
def column_stack(tup): ...
def dstack(tup): ...
def array_split(ary, indices_or_sections, axis=...): ...
def split(ary, indices_or_sections, axis=...): ...
def hsplit(ary, indices_or_sections): ...
def vsplit(ary, indices_or_sections): ...
def dsplit(ary, indices_or_sections): ...
def get_array_prepare(*args): ...
def get_array_wrap(*args): ...
def kron(a, b): ...
def tile(A, reps): ...



from __future__ import annotations

from typing import Any
import numpy as np

AR_f8: np.ndarray[Any, np.dtype[np.float64]] = np.array([1.0])
AR_i8: np.ndarray[Any, np.dtype[np.int_]] = np.array([1])

b_f8 = np.broadcast(AR_f8)
b_i8_f8_f8 = np.broadcast(AR_i8, AR_f8, AR_f8)

next(b_f8)
next(b_i8_f8_f8)

b_f8.reset()
b_i8_f8_f8.reset()

b_f8.index
b_i8_f8_f8.index

b_f8.iters
b_i8_f8_f8.iters

b_f8.nd
b_i8_f8_f8.nd

b_f8.ndim
b_i8_f8_f8.ndim

b_f8.numiter
b_i8_f8_f8.numiter

b_f8.shape
b_i8_f8_f8.shape

b_f8.size
b_i8_f8_f8.size



from typing import List

__all__: List[str]

def histogram_bin_edges(a, bins=..., range=..., weights=...): ...
def histogram(a, bins=..., range=..., normed=..., weights=..., density=...): ...
def histogramdd(sample, bins=..., range=..., normed=..., weights=..., density=...): ...
